@@ -14,6 +14,7 @@ Usage::
         ListAnalyzersPaginator,
         ListArchiveRulesPaginator,
         ListFindingsPaginator,
+        ListPolicyGenerationsPaginator,
         ValidatePolicyPaginator,
     )
 
@@ -28,6 +29,7 @@ Usage::
     list_analyzers_paginator: ListAnalyzersPaginator = client.get_paginator("list_analyzers")
     list_archive_rules_paginator: ListArchiveRulesPaginator = client.get_paginator("list_archive_rules")
     list_findings_paginator: ListFindingsPaginator = client.get_paginator("list_findings")
+    list_policy_generations_paginator: ListPolicyGenerationsPaginator = client.get_paginator("list_policy_generations")
     validate_policy_paginator: ValidatePolicyPaginator = client.get_paginator("validate_policy")
     ```
 """
@@ -39,6 +41,7 @@ from mypy_boto3_accessanalyzer.paginator import (
     ListAnalyzersPaginator,
     ListArchiveRulesPaginator,
     ListFindingsPaginator,
+    ListPolicyGenerationsPaginator,
     ValidatePolicyPaginator,
 )
 
@@ -54,5 +57,6 @@ __all__ = (
     "ListAnalyzersPaginator",
     "ListArchiveRulesPaginator",
     "ListFindingsPaginator",
+    "ListPolicyGenerationsPaginator",
     "ValidatePolicyPaginator",
 )
